fold_ple_evals

Function fold_ple_evals 

pub fn fold_ple_evals<F, EF>(
    l_skip: usize,
    mat: StridedColMajorMatrixView<'_, F>,
    is_rot: bool,
    r: EF,
) -> ColMajorMatrix<EF>
where F: TwoAdicField, EF: ExtensionField<F> + TwoAdicField,
mat is a matrix of the evaluations on hyperprism D_n of a prismalinear extensions of the columns. We “fold” it by evaluating the prismalinear polynomials at r in the univariate variable Z.

If n < 0, then we evaluate mat at r^{-n}, which is equivalent to folding the lift of mat.