pub fn sumcheck_multilinear<SC: StarkProtocolConfig, F: Field, TS: FiatShamirTranscript<SC>>(
transcript: &mut TS,
evals: &[F],
) -> Result<(SumcheckCubeProof<SC::EF>, Vec<SC::EF>), SumcheckError>where
SC::EF: ExtensionField<F>,Expand description
“Plain” sumcheck on a multilinear polynomial
The slice evals contains the evaluations of a multilinear polynomial on boolean hypercube.
The length of evals should equal 2^n where n is hypercube dimension.
Returns the sumcheck proof containing all prover messages and the random evaluation point.