sumcheck_prismalinear

Function sumcheck_prismalinear 

pub fn sumcheck_prismalinear<SC: StarkProtocolConfig, F, TS: FiatShamirTranscript<SC>>(
    transcript: &mut TS,
    l_skip: usize,
    evals: &[F],
) -> Result<(SumcheckPrismProof<SC::EF>, Vec<SC::EF>), SumcheckError>
where F: TwoAdicField, SC::EF: ExtensionField<F> + TwoAdicField,
“Plain” sumcheck on a prismalinear polynomial with Gruen’s univariate skip.

The slice evals contains the evaluations of a prismalinear polynomial on the hyperprism. The length of evals should equal 2^{l_skip + n} where l_skip is the univariate skip parameter and n is hypercube dimension. Indexing is such that evals[x * 2^{l_skip} + i] is the evaluation of f(omega_D^i, x) where omega_D is a fixed generator of the univariate skip domain D (which is a subgroup of F^*).

Returns the sumcheck proof containing all prover messages and the random evaluation point.