pub struct SumcheckPrismProof<EF> {
pub sum_claim: EF,
pub s_0: UnivariatePoly<EF>,
pub round_polys_eval: Vec<Vec<EF>>,
pub eval_claim: EF,
}Fields
sum_claim: EFs_0: UnivariatePoly<EF>The univariate polynomial s_0 in coefficient form.
round_polys_eval: Vec<Vec<EF>>for each hypercube round, the evaluations of univariate polynomial s_round at {1, ..., deg(s_round)}. See SumcheckCubeProof for details.
eval_claim: EFFinal evaluation claim of the polynomial at the random vector r